@@ -254,7 +254,11 @@ size_t Archive::ReadHeader15()
         hd->SplitAfter=(hd->Flags & LHD_SPLIT_AFTER)!=0;
         hd->Encrypted=(hd->Flags & LHD_PASSWORD)!=0;
         hd->SaltSet=(hd->Flags & LHD_SALT)!=0;
+        
+        // RAR versions earlier than 2.0 do not set the solid flag
+        // in file header. They use only a global solid archive flag.
         hd->Solid=FileBlock && (hd->Flags & LHD_SOLID)!=0;
+
         hd->SubBlock=!FileBlock && (hd->Flags & LHD_SOLID)!=0;
         hd->Dir=(hd->Flags & LHD_WINDOWMASK)==LHD_DIRECTORY;
         hd->WinSize=hd->Dir ? 0:0x10000<<((hd->Flags & LHD_WINDOWMASK)>>5);
@@ -1000,7 +1004,7 @@ void Archive::ProcessExtra50(RawRead *Raw,size_t ExtraSize,const BaseBlock *bb)
               {
                 std::vector<char> NameU((size_t)NameSize); // UTF-8 name.
                 Raw->GetB(&NameU[0],(size_t)NameSize);
-                // If starts from 0, the name was longer han reserved space
+                // If starts from 0, the name was longer than reserved space
                 // when saving this extra field.
                 if (NameU[0]!=0)
                 {
@@ -1014,11 +1018,11 @@ void Archive::ProcessExtra50(RawRead *Raw,size_t ExtraSize,const BaseBlock *bb)
             if ((Flags & MHEXTRA_METADATA_CTIME)!=0)
               if ((Flags & MHEXTRA_METADATA_UNIXTIME)!=0)
                 if ((Flags & MHEXTRA_METADATA_UNIX_NS)!=0)
-                  hd->OrigCtime.SetUnixNS(Raw->Get8());
+                  hd->OrigTime.SetUnixNS(Raw->Get8());
                 else
-                  hd->OrigCtime.SetUnix((time_t)Raw->Get4());
+                  hd->OrigTime.SetUnix((time_t)Raw->Get4());
               else
-                hd->OrigCtime.SetWin(Raw->Get8());
+                hd->OrigTime.SetWin(Raw->Get8());
           }
           break;
       }
